@@ -30,14 +30,18 @@ def _implement_clone(repository: str, directory: Optional[str]) -> None:
 
     click.secho("> Forking:", bold=True)
 
-    forked_repo = origin_repo.create_fork()
+    if origin_repo.visibility == "private":
+        click.secho(f"Repository '{name}' is private, skip the fork process.\n")
+        target_repo = origin_repo
+    else:
+        target_repo = origin_repo.create_fork()
 
-    click.echo(f"Repository forked: {click.style(forked_repo.full_name, bold=True)}\n")
+        click.echo(f"Repository forked: {click.style(target_repo.full_name, bold=True)}\n")
 
     directory = directory if directory else name.split("/", 1)[1]
     try:
         click.secho("> Cloning:", bold=True)
-        run(["git", "clone", forked_repo.ssh_url, directory], env=ENV, check=True)
+        run(["git", "clone", target_repo.ssh_url, directory], env=ENV, check=True)
 
         os.chdir(directory)
 
@@ -55,8 +59,9 @@ def _implement_clone(repository: str, directory: Optional[str]) -> None:
     if os.path.exists(_PRECOMMIT_CONFIG_PATH):
         click.secho("> Installing 'pre-commit' scripts:", bold=True)
         _install_precommit_scripts()
+        click.echo()
 
-    click.secho("\n> Success!", fg="green")
+    click.secho("> Success!", fg="green")
 
 
 def _get_repo_name(repository: str) -> str:
@@ -104,7 +109,7 @@ def _install_precommit_scripts() -> None:
 
     config: Dict[str, Any] = load_config(_PRECOMMIT_CONFIG_PATH)
 
-    stages: List[str] = config.get("default_stages", [])
+    stages: List[str] = config["default_install_hook_types"].copy()
     for repo in config["repos"]:
         for hook in repo["hooks"]:
             stages.extend(hook.get("stages", []))
